local clock={}
clock.effect = love.graphics.newShader[[

extern vec2		screen;
extern number	sec;
extern number	mn;
extern number	hr;
extern number	size;

number pi	= atan(1.0) * 4.0;
number tau	= atan(1.0) * 8.0;
number xx	= 155.0;

number scale = size / 2000.0;

// Distance to a line segment.
number dfLine( vec2 start, vec2 end, vec2 uv )
{
	start		*= scale;
	end			*= scale;
	vec2 line 	= end - start;
	number frac = dot(uv - start,line) / dot(line,line);
	return distance(start + line * clamp(frac, 0.0, 1.0), uv);
}

// Distance to the edge of a circle.
number dfCircle(vec2 origin, number radius, vec2 uv)
{
	origin *= scale;
	radius *= scale;
	return abs( length( uv - origin ) - radius );
}

// Distance to an arc.
number dfArc( vec2 origin, number start, number sweep, number radius, vec2 uv )
{
	origin	*= scale;
	radius	*= scale;
	uv		-= origin;
	uv		*= mat2( cos(start), sin(start),-sin(start), cos(start) );

	number offs	= ( sweep / 2.0 - pi );
	number ang	= mod( atan( uv.y, uv.x ) - offs, tau ) + offs;
	ang			= clamp( ang, min( 0.0, sweep ), max( 0.0, sweep ) );

	return distance( radius * vec2( cos( ang ), sin( ang ) ), uv );
}

number drawNumber( number dist, int i, vec2 pos, vec2 uv )
{
	uv	= +uv + ( vec2( number(i) * 100.0, 0.0 ) - pos ) * scale;

	if ( i == 1 )
	{
		dist = min( dist, dfLine( vec2( 150.0, 150.0 ), vec2( 150.0,0.0 ), uv ) );
	}
	else if ( i == 2 )
	{
		dist = min( dist, dfLine( vec2( 300.000,   0.000 ), vec2(200.000,  0.000 ),  uv ) );
		dist = min( dist, dfLine( vec2( 216.371,  26.726 ), vec2(272.714, 55.457 ),  uv ) );
		dist = min( dist, dfArc( vec2(  250.000, 100.000 ), 5.184, 4.241, 50.0, uv ) );
		dist = min( dist, dfArc( vec2(  230.000,   0.000 ), 2.042, 1.099, 30.0, uv ) );
	}
	else if ( i == 3 )
	{
		dist = min( dist, dfLine( vec2( 300.0,150.0), vec2(400.0,150.0), uv ) );
		dist = min( dist, dfLine( vec2( 400.0,150.0), vec2(350.0,100.0), uv ) );
		dist = min( dist, dfArc( vec2(  350.0, 50.0), 3.142, 4.712, 50.0, uv ) );
	}
	else if ( i == 4 )
	{
		dist = min( dist, dfLine( vec2( 470.0,150.0), vec2( 400.0,50.0 ), uv ) );
		dist = min( dist, dfLine( vec2( 400.0, 50.0), vec2( 500.0,50.0 ), uv ) );
		dist = min( dist, dfLine( vec2( 470.0,120.0), vec2( 470.0, 0.0 ), uv ) );
	}
	else if ( i == 5 )
	{
		dist = min( dist, dfArc( vec2(  550.0, 50.0), 3.142, 5.356, 50.0,  uv ) );
		dist = min( dist, dfLine( vec2( 600.0,150.0), vec2(530.0,150.0), uv ) );
		dist = min( dist, dfLine( vec2( 530.0,150.0), vec2(520.0, 90.0), uv ) );
	}
	else if ( i == 6 )
	{
		dist = min( dist, dfLine( vec2(  607.0,75.0), vec2( 650.0, 150.0 ), uv ) );
		dist = min( dist, dfCircle( vec2(650.0,50.0), 50.0, uv ) );
	}
	else if ( i == 7 )
	{
		dist = min( dist, dfLine( vec2( 700.0,150.0), vec2( 800.0,150.0), uv ) );
		dist = min( dist, dfLine( vec2( 800.0,150.0), vec2( 750.0,  0.0), uv ) );
	}
	else if ( i == 8 )
	{
		dist = min( dist, dfCircle( vec2( 850.0, 40.0 ), 40.0, uv ) );
		dist = min( dist, dfCircle( vec2( 850.0,115.0 ), 35.0, uv ) );
	}
	else if ( i == 9 )
	{
		dist = min(dist, dfLine( vec2(   993.3, 75.0 ), vec2( 950.0, 0.0 ), uv ) );
		dist = min(dist, dfLine( vec2(   993.3, 75.0 ), vec2( 950.0, 0.0 ), uv ) );
		dist = min(dist, dfCircle( vec2( 950.0,100.0 ), 50.0, uv ) );
	}
	else if(i == 0)
	{
		dist = min( dist, dfLine( vec2( 100.0,100.0 ), vec2( 100.0,50.0 ), uv ) );
		dist = min( dist, dfLine( vec2(   0.0,100.0 ), vec2(   0.0,50.0 ), uv ) );
		dist = min( dist, dfArc( vec2(   50.0,100.0 ),0.000, 3.142, 50.0, uv ) );
		dist = min( dist, dfArc( vec2(   50.0, 50.0 ),3.142, 3.142, 50.0, uv ) );
	}
	return dist;
}

vec4 effect( vec4 color, Image tex, vec2 tc, vec2 pc )
{
	vec2 aspect = screen.xy / screen.y;

	vec2 uv		= gl_FragCoord.xy / screen.y - aspect/2.0;
	uv			-= vec2(-1000.0,-150.0)*scale/2.0;

	number dist = 1e6;

	number t;
	int num;

	t		= sec;
	num		= int( t - number( int( t / 10.0 ) ) * 10.0 );
	dist	= drawNumber( dist, num, vec2( xx + 590.0, 0.0 ), uv );
	t		= t / 10.0;
	num		= int( t - number( int( t / 10.0 ) ) * 10.0 );
	dist	= drawNumber( dist, num, vec2( xx + 480.0, 0.0 ), uv );

	t		= mn;
	num		= int( t - number( int( t / 10.0 ) ) * 10.0 );
	dist	= drawNumber( dist, num, vec2( xx + 350.0, 0.0 ), uv );
	t		= t / 10.0;
	num		= int( t - number( int( t / 10.0 ) ) * 10.0 );
	dist	= drawNumber( dist, num, vec2( xx + 240.0, 0.0 ), uv );

	t		= hr;
	num		= int( t - number( int( t / 10.0 ) ) * 10.0 );
	dist	= drawNumber( dist, num, vec2( xx + 110.0, 0.0 ), uv );
	t		= t / 10.0;
	num		= int(t - number( int( t / 10.0 ) ) * 10.0);
	dist	= drawNumber( dist, num, vec2( xx, 0.0 ), uv );

	dist	= min(dist,dfCircle( vec2( 225 + xx,  50.0 ), 5.0, uv ) );
	dist	= min(dist,dfCircle( vec2( 225 + xx, 100.0 ), 5.0, uv ) );
	dist	= min(dist,dfCircle( vec2( 465 + xx,  50.0 ), 5.0, uv ) );
	dist	= min(dist,dfCircle( vec2( 465 + xx, 100.0 ), 5.0, uv ) );

	vec3 clr = vec3( 0.0, 0.0, 0.2 );

	number shade = 0.01 / dist;

	clr += vec3(1.0,0.2,0.1) * shade;

	return vec4( clr , 1.0 );
}

]]

return clock
